==> nextcloud-23.0.9.tgz: nextcloud/apps/serverinfo/l10n/sl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Podatki CPE niso na voljo",
    "Users" : "Uporabniki",
    "Groups" : "Skupine",
    "Links" : "Povezave",
    "Emails" : "Elektronski naslovi",
    "Federated sent" : "Zvezno poslano",
    "Federated received" : "Zvezno prejeto",
    "Talk conversations" : "Pogovori Talk",
    "24 hours" : "24 ur",
    "1 hour" : "1 ura",
    "5 mins" : "5 minut",
    "Copy" : "Kopiraj",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "System" : "Sistem",
    "Monitoring" : "Sistemska dejavnost",
    "Monitoring app with useful server information" : "Program za spremljanje delovanja sistema z različnimi podrobnostmi obremenitve strežnika",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Omogoča prikaz različnih podrobnosti strežnika, kot so obremenitev CPE, zasedenost pomnilnika in prostora, števila uporabnikov in drugo.",
    "Temperature" : "Temperatura",
    "Load" : "Obremenitev",
    "Memory" : "Pomnilnik",
    "Disk" : "Disk",
    "Size:" : "Velikost:",
    "You will get a notification once one of your disks is nearly full." : "Obvestilo bo poslano, ko bo katerikoli disk skoraj polno zaseden.",
    "Files:" : "Datoteke:",
    "Storages:" : "Shrambe:",
    "Free Space:" : "Prostor:",
    "Network" : "Omrežje",
    "Active users" : "Dejavni uporabniki",
    "Total users:" : "Število uporabnikov:",
    "Shares" : "Souporaba",
    "PHP" : "Okolje PHP",
    "Version:" : "Različica:",
    "Upload max size:" : "Omejitev velikosti pošiljanja:",
    "Database" : "Podatkovna zbirka",
    "Type:" : "Vrsta:",
    "External monitoring tool" : "Zunanje orodje za nadzor",
    "You can connect an external monitoring tool by using this end point:" : "Povezava do zunanjega orodja za spremljanje delovanja prek končne točke:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Pripenjanje zapisa » ?format=json « na konec naslova URL omogoči izpis podatkov v zapisu JSON.",
    "Load average" : "Povprečna obremenitev",
    "Last minute" : "zadnja minuta",
    "Memory info not available" : "Podrobnosti o pomnilniku niso na voljo",
    "Total" : "Skupaj",
    "Current usage" : "Trenutna zasedenost",
    "Mails" : "Sporočila",
    "Operating System" : "Operacijski sistem",
    "CPU" : "CPE",
    "Server time" : "Čas strežnika",
    "Uptime" : "Čas delovanja",
    "Mount" : "Prilop",
    "Filesystem" : "Datotečni sistem",
    "Size" : "Velikost",
    "Available" : "Na voljo",
    "Used" : "Zasedeno",
    "Hostname" : "Ime gostitelja",
    "DNS" : "Domensko ime DNS",
    "Gateway" : "Prehod",
    "Status" : "Stanje",
    "Speed" : "Hitrost",
    "MAC" : "Naslov MAC",
    "IPv4" : "Naslov IPv4",
    "IPv6" : "Naslov IPv6",
    "Memory Limit:" : "Omejitev pomnilnika:",
    "Max Execution Time:" : "Največji čas izvajanja:",
    "Files" : "Datoteke",
    "Version" : "Različica",
    "Type" : "Vrsta"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-24.0.9.tgz: nextcloud/apps/serverinfo/l10n/sl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Podatki CPE niso na voljo",
    "Users" : "Uporabniki",
    "Groups" : "Skupine",
    "Links" : "Povezave",
    "Emails" : "Elektronski naslovi",
    "Federated sent" : "Zvezno poslano",
    "Federated received" : "Zvezno prejeto",
    "Talk conversations" : "Pogovori Talk",
    "24 hours" : "24 ur",
    "1 hour" : "1 ura",
    "5 mins" : "5 minut",
    "Copy" : "Kopiraj",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "System" : "Sistem",
    "Monitoring" : "Sistemska dejavnost",
    "Monitoring app with useful server information" : "Program za spremljanje delovanja sistema z različnimi podrobnostmi obremenitve strežnika",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Omogoča prikaz različnih podrobnosti strežnika, kot so obremenitev CPE, zasedenost pomnilnika in prostora, števila uporabnikov in drugo.",
    "Temperature" : "Temperatura",
    "Load" : "Obremenitev",
    "Memory" : "Pomnilnik",
    "Disk" : "Disk",
    "Size:" : "Velikost:",
    "You will get a notification once one of your disks is nearly full." : "Obvestilo bo poslano, ko bo katerikoli disk skoraj polno zaseden.",
    "Files:" : "Datoteke:",
    "Storages:" : "Shrambe:",
    "Free Space:" : "Prostor:",
    "Network" : "Omrežje",
    "Active users" : "Dejavni uporabniki",
    "Total users:" : "Število uporabnikov:",
    "Shares" : "Souporaba",
    "PHP" : "Okolje PHP",
    "Version:" : "Različica:",
    "Upload max size:" : "Omejitev velikosti pošiljanja:",
    "Database" : "Podatkovna zbirka",
    "Type:" : "Vrsta:",
    "External monitoring tool" : "Zunanje orodje za nadzor",
    "You can connect an external monitoring tool by using this end point:" : "Povezava do zunanjega orodja za spremljanje delovanja prek končne točke:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Pripenjanje zapisa » ?format=json « na konec naslova URL omogoči izpis podatkov v zapisu JSON.",
    "Operating System" : "Operacijski sistem",
    "CPU" : "CPE",
    "Server time" : "Čas strežnika",
    "Uptime" : "Čas delovanja",
    "Mount" : "Prilop",
    "Filesystem" : "Datotečni sistem",
    "Size" : "Velikost",
    "Available" : "Na voljo",
    "Used" : "Zasedeno",
    "Files" : "Datoteke",
    "Storages" : "Shrambe",
    "Free Space" : "Nezaseden prostor",
    "Hostname" : "Ime gostitelja",
    "DNS" : "Domensko ime DNS",
    "Gateway" : "Prehod",
    "Status" : "Stanje",
    "Speed" : "Hitrost",
    "MAC" : "Naslov MAC",
    "IPv4" : "Naslov IPv4",
    "IPv6" : "Naslov IPv6",
    "Total users" : "Število uporabnikov",
    "Version" : "Različica",
    "Memory limit" : "Omejitev pomnilnika",
    "Max execution time" : "Največji čas izvajanja",
    "Upload max size" : "Omejitev velikosti pošiljanja",
    "Type" : "Vrsta"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
